@@ -32,7 +32,13 @@ LOG = logging.getLogger(__name__)
 
 
 def _get_columns(item):
-    return utils.get_osc_show_columns_for_sdk_resource(item, {})
+    column_map = {}
+    hidden_columns = ['location']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 def _get_ranges(item):
